summaryrefslogtreecommitdiff
path: root/src/arch/arm/v7/operands/shift.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/arch/arm/v7/operands/shift.h')
-rw-r--r--src/arch/arm/v7/operands/shift.h27
1 files changed, 23 insertions, 4 deletions
diff --git a/src/arch/arm/v7/operands/shift.h b/src/arch/arm/v7/operands/shift.h
index 3351056..1169946 100644
--- a/src/arch/arm/v7/operands/shift.h
+++ b/src/arch/arm/v7/operands/shift.h
@@ -33,6 +33,9 @@
+/* --------------------- MANIPULATION D'OPERANDES INDIVIDUELLES --------------------- */
+
+
#define G_TYPE_ARMV7_SHIFT_OPERAND g_armv7_shift_operand_get_type()
#define G_ARMV7_SHIFT_OPERAND(obj) (G_TYPE_CHECK_INSTANCE_CAST((obj), g_armv7_shift_operand_get_type(), GArmV7ShiftOperand))
#define G_IS_ARMV7_SHIFT_OPERAND(obj) (G_TYPE_CHECK_INSTANCE_TYPE((obj), g_armv7_shift_operand_get_type()))
@@ -41,17 +44,17 @@
#define G_ARMV7_SHIFT_OPERAND_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS((obj), G_TYPE_ARMV7_SHIFT_OPERAND, GArmV7ShiftOperandClass))
/* Définition d'un opérande visant une liste d'opérandes Dalvik (instance) */
typedef struct _GArmV7ShiftOperand GArmV7ShiftOperand;
/* Définition d'un opérande visant une liste d'opérandes Dalvik (classe) */
typedef struct _GArmV7ShiftOperandClass GArmV7ShiftOperandClass;
/* Indique le type défini par la GLib pour une liste d'arguments Dalvik. */
GType g_armv7_shift_operand_get_type(void);
-/* Crée un réceptacle pour opérandes Dalvik servant d'arguments. */
+/* Crée un réceptacle pour opérande de décallage ARMv7. */
GArchOperand *g_armv7_shift_operand_new(SRType, GArchOperand *);
/* Indique la forme de décallage représenté. */
@@ -62,4 +65,20 @@ GArchOperand *g_armv7_shift_operand_get_shift_value(const GArmV7ShiftOperand *);
+/* -------------------------- PARTAGES DE CONTENUS UNIQUES -------------------------- */
+
+
+/* Met en place les mécanismes de partage des décallages ARMv7. */
+bool init_armv7_shift_operand_sharing(void);
+
+/* Imprime des statistiques quant aux partages dans l'archi. */
+#ifdef DEBUG_DUMP_STATS
+void dump_armv7_shift_operand_share_stats(void);
+#endif
+
+/* Supprime les mécanismes de partage des décallages ARMv7. */
+void exit_armv7_shift_operand_sharing(void);
+
+
+
#endif /* _ARCH_ARM_V7_OPERANDS_SHIFT_H */
@@ -41,17 +44,17 @@
#define G_ARMV7_SHIFT_OPERAND_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS((obj), G_TYPE_ARMV7_SHIFT_OPERAND, GArmV7ShiftOperandClass))
-/* Définition d'un opérande visant une liste d'opérandes Dalvik (instance) */
+/* Définition d'un opérande visant une opérande de décallage ARMv7 (instance) */
typedef struct _GArmV7ShiftOperand GArmV7ShiftOperand;
@@ -41,17 +44,17 @@
typedef struct _GArmV7ShiftOperand GArmV7ShiftOperand;
-/* Définition d'un opérande visant une liste d'opérandes Dalvik (classe) */
+/* Définition d'un opérande visant une opérande de décallage ARMv7 (classe) */
typedef struct _GArmV7ShiftOperandClass GArmV7ShiftOperandClass;
@@ -41,17 +44,17 @@
typedef struct _GArmV7ShiftOperandClass GArmV7ShiftOperandClass;
-/* Indique le type défini par la GLib pour une liste d'arguments Dalvik. */
+/* Indique le type défini par la GLib pour une opérande de décallage ARMv7. */
GType g_armv7_shift_operand_get_type(void);